+++
title = "Page using the Headless Page Bundle X"
layout = "headless-bundle-single"
tags = ["page-bundles", "headless", "layout"]
draft = false
+++

This is a regular page. Below content is fetched from the **headless
page bundle** `headless-page-bundle-x`.

-   [Source (`index.md`)](https://raw.githubusercontent.com/kaushalmodi/ox-hugo/master/test/site/content/bundles/headless-page-bundle-x/index.md) of the referenced headless bundle.
